"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpiralAbyss = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const clientCache_1 = require("../client/clientCache");
const error_1 = require("../utils/error");
class SpiralAbyss {
    constructor() {
        Object.defineProperty(this, "cache", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new clientCache_1.ClientCache()
        });
    }
    /**
       * @param {string} uid Genshin Impact game uid
       * @param {Language} language The response language
       * @param {string} cookie The cookie to use for the request
       */
    async get(uid, language, cookie, previous) {
        const instance = new request_1.request({
            withDS: true
        });
        instance.setLanguage(language);
        const res = await instance.get("spiralAbyss", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            "Cookie": cookie,
        }, {
            "server": (0, getServer_1.checkServerRegion)(uid),
            "role_id": uid,
            "schedule_type": `${previous ? "2" : "1"}`,
        });
        if (res.retcode === 0) {
            const { data } = res;
            this.cache.set(uid, data);
            return data;
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
}
exports.SpiralAbyss = SpiralAbyss;
